<no title> — CALCEPH - Octave/Matlab language 3.4.1 documentation

The order of derivatives

> - = 0 , only the position is computed. The first three numbers of PVAJ are valid for the results.
> - = 1 , only the position and velocity are computed. The first six numbers of PVAJ are valid for the results.
> - = 2 , only the position, velocity and acceleration are computed. The first nine numbers of PVAJ are valid for the results.
> - = 3 , the position, velocity and acceleration and jerk are computed. The first twelve numbers of PVAJ are valid for the results.

If order equals to 1, the behavior of `CalcephBin.compute_order()` is the same as `CalcephBin.compute_unit()`.